@@ -50,19 +50,23 @@ sub read_patch_series {
         next unless $pname =~ /\w/;    # skip empty lines
         my $obj = $hash->fetch_with_id($pname);
         eval { $obj->init; };
-        my $e;
-        if ($e = Exception::Class->caught('Config::Model::Exception::Syntax')) {
+        my $e = $@;
+        if (ref($e) and $e ->isa('Config::Model::Exception::Syntax')) {
             if ( $args->{check} eq 'yes' ) {
-                my $msg = $e ->message. ". Use -force option to override" ;
-                ref($e) -> throw(message => $msg);
+                my $msg = $e ->message;
+                $e->message($msg. ". Use -force option to override" );
+                $e -> rethrow();
             }
             else {
                 warn "Warning: Ignoring patch $pname: ", $e->message,"\n";
             }
             $hash->delete($pname);
         }
-        elsif ( $e = Exception::Class->caught() ) {
-            ref $e ? $e->rethrow : die $e;
+        elsif (ref($e)) {
+            $e->rethrow ;
+        }
+        elsif ($e) {
+            die $e;
         }
         elsif ($logger->is_info) {
             my $location = $obj->name;
