@@ -73,7 +73,7 @@ sub read {
         # Some people use 'File' to declare copyright info for a single file.
         # While this is correct grammatically, it tends to be PITA
         if (my $file_section = delete $section{file}) {
-            $logger->warn("Found File section. This one is converted in Files section (mind the plural)");
+            warn("copyright line $section_line: section 'File' is converted in 'Files' section (mind the plural)\n");
             $file_section->[2] = 'changed file section into files section' ;
             $section{files} //= $file_section ; # no clobber of good section
         }
@@ -94,7 +94,7 @@ sub read {
         }
 
         if (defined $section{licence}) {
-            $logger->warn("Found UK spelling for license. It will be converted to US spelling");
+            warn("copyright line $section_line: Converting UK spelling for license in US spelling\n");
             $section{license} = delete $section{licence} ;# FIXME: use notify_change
             $section{license}[2] = 'changed uk spelling for license (was licence)'; # is altered
         } 
@@ -107,9 +107,12 @@ sub read {
             }
             if ($v =~ /,/) {
                 $logger->warn("Found comma in Files line, cleaning up");
-                $v =~ s/ *,+[ \t]*/ /g;
-                $v =~ s/^\s*|\s*$//g;
+                $v =~ s/,+/ /g;
             }
+            $v =~ s/(?<=\w)[ \t]+/ /g;
+            $v =~ s/[ \t]+\n/\n/g;
+            $v =~ s/^\s*|\s*$//g;
+            $logger->debug("Files paragraph after cleanup $l: '$v'");
             $file_paragraph{$v} = $section_ref ;
             push @file_names, $v ;
         }
@@ -138,7 +141,7 @@ sub read {
                     parsed_line => $section_line 
                 );
             }
-            $logger->warn("Dropping unknown paragraph from section $section_nb line $section_line");
+            $logger->warn("copyright line $section_line: Dropping unknown paragraph");
         }
     }
     
@@ -212,11 +215,12 @@ sub read {
             my $key = $section->[$i];
             my ($v,$l,$a) = @{$section->[$i+1]};
             #$v =~ s/^\s+//; # remove all leading spaces 
-            $logger->info("reading key $key from file paragraph '$file_name' line $l for ".$object->name);
-            $logger->debug("$key value: '$v'");
 
             next if $key =~ /^files$/i; # already done just before this loop
 
+            $logger->info("reading key $key from file paragraph '$file_name' line $l for ".$object->name);
+            $logger->debug("$key value: '$v'");
+
             if ($key =~ /^licen[sc]e$/i) {
                 my $lic_node = $object->fetch_element('License') ;
                 _store_license_info ($lic_node, $key, $v, $a, $check);
