@@ -42,20 +42,21 @@ sub parse_dpkg_lines {
     # [keyword, [ value, line_nb, altered , comment ] ])
     my @res ; 
     
-    foreach (@$lines) {
-        $logger->trace("Parsing line $line_nb '$_'");
-        if (/^#/) { # comment are always located before the keyword (hopefully)
+    foreach my $l (@$lines) {
+        $logger->trace("Parsing line $line_nb '$l'");
+        if ( $l =~ /^#/ ) { # comment are always located before the keyword (hopefully)
             Config::Model::Exception::Syntax->throw (
                 object => $self,
                 parsed_line => $line_nb,
                 message => "Comments are not allowed",
             ) unless $comment_allowed;
-            my $c = $_ ;
+            my $c = $l ;
             $c =~ s/#\s// ;
             push @comments, $c ;
         }
-        elsif (/^([\w\-]+)\s*:/) {  # keyword: 
-            my ($field,$text) = split /\s*:\s*/,$_,2 ;
+        elsif ( $l =~ /^([\w\-]+)\s*:/ ) {  # keyword:
+            my ($field,$text) = split /\s*:\s*/,$l,2 ;
+            $text =~ s/\s+$//;
             $key = $field ;
             $logger->trace("line $line_nb start new field $key with '$text'");
 
@@ -66,8 +67,8 @@ sub parse_dpkg_lines {
             @comments = () ;
             $store_ref = \$store_list->[$#$store_list][0] ;
         }
-        elsif ($key and /^\s*$/) {     # first empty line after a section
-            $logger->trace("empty line: starting new section");
+        elsif ( $key and $l =~ /^\s*$/ ) {     # first empty line after a section
+            $logger->trace("empty line $line_nb: starting new section");
             $key = '';
             push @res, $section_line, $store_list if @$store_list ; # don't store empty sections 
             $store_list = [] ;
@@ -75,24 +76,24 @@ sub parse_dpkg_lines {
             chomp $$store_ref if defined $$store_ref; # remove trailing \n
             undef $store_ref ; # to ensure that next line contains a keyword
         }
-        elsif (/^\s*$/) {     # "extra" empty line
-            $handle_garbage->($_, $line_nb) if $handle_garbage ;
+        elsif ( $l =~ /^\s*$/ ) {     # "extra" empty line
+            $handle_garbage->($l, $line_nb) if $handle_garbage ;
             $logger->trace("extra empty line: skipped");
             # just skip it
         } 
-        elsif (/^\s+\.$/) {   # line with a single dot
+        elsif ( $l =~ /^\s+\.$/) {   # line with a single dot
             $logger->trace("dot line: adding blank line to field $key");
             _store_line($store_ref,"",$check,$line_nb) ;
         }
-        elsif (s/^\s//) {     # non empty line
-            $logger->trace("text line: adding '$_' to field $key");
-            _store_line($store_ref,$_ , $check,$line_nb);
+        elsif ( $l =~ s/^\s//) {     # non empty line
+            $logger->trace("text line: adding '$l' to field $key");
+            _store_line($store_ref,$l , $check,$line_nb);
         }
         elsif ($handle_garbage) {
-            $handle_garbage->($_, $line_nb) ;
+            $handle_garbage->($l, $line_nb) ;
         }
         else {
-            my $msg = "DpkgSyntax error: Invalid line (missing ':' ?) : $_" ;
+            my $msg = "DpkgSyntax error: Invalid line (missing ':' ?) : $l" ;
             Config::Model::Exception::Syntax -> throw ( message => $msg, parsed_line => $line_nb ) 
                 if $check eq 'yes' ; 
             $logger->error($msg) if $check eq 'skip';
