@@ -35,13 +35,35 @@ sub normalize_path ($self,$path) {
 
 my $dumper = Config::Model::DumpAsData->new;
 
+sub _say ($self,$msg) {
+    say $msg unless $self->{quiet};
+}
+
+sub _get_old_data ($old_split_files, $old_split_dirs, $path) {
+    my $data = delete $old_split_files->{$path};
+
+    if (not $data) {
+        foreach my $dir (reverse sort keys $old_split_dirs->%*) {
+            my $re = $dir;
+            $re =~ s/\*$//;
+            if ($path =~ /^$re/) {
+                $data = $old_split_dirs->{$dir}; # do not delete
+                last;
+            }
+        }
+    }
+    return defined $data ? dclone($data) : {};
+}
+
 # $args{in} can contains the output of licensecheck (for tests)
 sub update ($self, %args) {
 
     my $files_obj = $self->grab("Files");
+    $self->{quiet} = $args{quiet} // 0;
 
     # explode existing path data to track deleted paths
     my %old_split_files;
+    my %old_split_dirs;
     my %debian_paths;
     foreach my $paths_str ($files_obj->fetch_all_indexes) {
         my $node = $files_obj->fetch_with_id($paths_str) ;
@@ -53,6 +75,7 @@ sub update ($self, %args) {
         else {
             foreach my $path ($self->split_path($paths_str)) {
                 $old_split_files{$path} = $data ;
+                $old_split_dirs{$path} = $data if $path =~ /\*$/;
             }
         }
     }
@@ -61,33 +84,53 @@ sub update ($self, %args) {
 
     # explode new data and merge with existing entries
     my %new_split_files;
-    my @data;
+    my @data = (undef);# id 0 is reserved for entries without info
     my %data_keys;
     foreach my $path ( sort keys $files->%* ) {
-        my ($c, $l) = $copyrights_by_id->[ $files->{$path} ]->@*;
+        my $id = $files->{$path};
+        next if $id == 0 and not defined $copyrights_by_id->[$id];
+        my ($c, $l) = $copyrights_by_id->[$id]->@*;
 
-        my $new_data = dclone (delete $old_split_files{$path} || {} );
+        my $new_data = _get_old_data(\%old_split_files, \%old_split_dirs, $path);
         my $old_cop = $new_data->{Copyright};
         my $old_lic = $new_data->{License}{short_name};
-        # say "load '$path' with '$c' ('$l') old '$old_cop' ('$old_lic')";
+        # $self->_say( "load '$path' with '$c' ('$l') old '$old_cop' ('$old_lic')");
         # clobber old data
         $new_data->{Copyright} = $c if ($c !~ /no-info-found|UNKNOWN/ or not $old_cop);
-        $new_data->{License}{short_name} = $l if ($l ne 'UNKNOWN');
+        $new_data->{License}{short_name} = $l if ($l ne 'UNKNOWN' or not $old_lic);
 
-        # create an inventory of different file copyright and license data
-        my $dumper = Data::Dumper->new([$new_data])->Sortkeys(1)->Indent(0);
-        my $datum_dump = $dumper->Dump;
-        my $d_key = $data_keys{$datum_dump};
-        if (not defined $d_key) {
-            push @data,$new_data;
-            $d_key = $data_keys{$datum_dump} = $#data;
+        # when all fails
+        $new_data->{Copyright} ||= 'UNKNOWN';
+        $new_data->{License}{short_name} ||= 'UNKNOWN';
+
+        # skip when no info is found in original data
+        my $d_key;
+        if ( $new_data->{Copyright} =~ /no-info-found|unknown/i
+            and $new_data->{License}{short_name} =~ /unknown/i) {
+            $data[0] //= $new_data;
+            $d_key = 0;
         }
+        else {
+            # create an inventory of different file copyright and license data
+            # this works like $copyrights_by_id but takes into account data coming
+            # from old copyright file like comments
+            my $dumper = Data::Dumper->new([$new_data])->Sortkeys(1)->Indent(0);
+            my $datum_dump = $dumper->Dump;
+            $d_key = $data_keys{$datum_dump};
 
+            if (not defined $d_key) {
+                push @data,$new_data;
+                # id 0 is special and is treated diffrently. It must not be used since
+                # entries without info are skipped. Hence @data was init with ('');
+                $d_key = $data_keys{$datum_dump} = $#data ;
+           }
+        }
         # explode path in subpaths and store id pointing to copyright data in there
         __create_tree_leaf_from_paths(\%new_split_files, $path, $d_key);
     }
 
     # at this point:
+    # * $copyrights_by_id is not longer used, its data and merged data are in @data
     # * @data contains a list of copyright/license data
     # * %new_split_files contains a tree matching a directory tree where each leaf
     #   is an integer index referencing
@@ -99,12 +142,12 @@ sub update ($self, %args) {
     my %preserved_path;
     # warn about old files (data may be redundant or obsolete though)
     foreach my $old_path (sort keys %old_split_files) {
-        # put back data matching an existing dir
+        # prepare to be able to put back data matching an existing dir
         if ($old_path eq '*' or ($old_path =~ m!(.*)/\*$! and $current_dir->is_dir($1))) {
             $preserved_path{$old_path} = delete $old_split_files{$old_path};
         }
         else {
-            say "Note: '$old_path' was removed from new upstream source";
+            $self->_say( "Note: '$old_path' was removed from new upstream source" );
         }
     }
 
@@ -118,10 +161,11 @@ sub update ($self, %args) {
     my @packed = __pack_files(\%new_split_files);
 
     # delete existing data in config tree. A more subtle solution to track which entry is
-    # deleted or altered (when individual files are removed, renamed) is too complex.
+    # deleted or altered (when individual files are removed, renamed) is too complex. The track
+    # would require to follow split files,
     $files_obj->clear;
 
-    # count license useage to dedice whether to add a global license
+    # count license useage to decide whether to add a global license
     # or a single entry. Skip unknown or public-domain licenses
     my %lic_usage_count;
     map { $lic_usage_count{$_}++ if $_ and not /unknown|public/i}
@@ -132,22 +176,52 @@ sub update ($self, %args) {
     foreach my $p (@packed) {
         my ($id, @paths) = $p->@*;
 
-        if ($paths[0] =~ /\.$/) {
+        next if $id == 0; # skip entries without info
+
+        my $datum = dclone($data[$id]);
+
+        # ditch old data when copyright data directory is found in source files
+        if ($paths[0] =~ /[*.]$/) {
             if (@paths > 1) {
                 die "Internal error: can't have dir path with file path: @paths";
             }
             my $p = $paths[0];
             $p =~ s/\.$/*/;
             my $old_data = delete $preserved_path{$p};
-            say "old dir data for $p overridden" if $old_data;
-            next;
+
+            my $using_old_data = 0;
+            if ($old_data) {
+                if ($datum->{Copyright} =~ /unknown|no-info-found/i) {
+                    $self->_say( "keeping copyright dir data for $p");
+                    $datum->{Copyright} = $old_data->{Copyright};
+                    $using_old_data = 1;
+                }
+                if ($datum->{License}{short_name} =~ /unknown|no-info-found/i) {
+                    $self->_say( "keeping license dir data for $p");
+                    $datum->{License}{short_name} = $old_data->{License}{short_name};
+                    $datum->{License}{full_license} = $old_data->{License}{full_license};
+                    $using_old_data = 1;
+                }
+                $self->_say( "old dir data for $p overridden by new data") unless $using_old_data;
+            }
+
+            if ($paths[0] =~ /\.$/) {
+                if ($using_old_data) {
+                    # fix path ending with '.' that contain merged info from old copyright file
+                    $paths[0] = $p;
+                } else {
+                    # skip writing data because it duplicates information
+                    # found in directory above above (as shown the path ending
+                    # with '/.')
+                    # $self->_say( "skipping redundant path ".$paths[0] );
+                    next;
+                }
+            }
         };
-        my $datum = dclone($data[$id]);
+
         my $path_str = $self->normalize_path(\@paths);
         my $l = $datum->{License}{short_name};
 
-        next unless $l ;
-
         my $norm_path_str = $self->normalize_path(\@paths);
 
         # if full_license is not provided in datum, check global license(s)
@@ -165,19 +239,29 @@ sub update ($self, %args) {
             if ($ok ne @sub_licenses) {
                 my $filler = "Please fill license $l from header of @paths";
                 if ($lic_count > 1 ) {
-                    say "Adding dummy global license text for license $l for path @paths";
+                    $self->_say( "Adding dummy global license text for license $l for path @paths");
                     map { $self->load(qq!License:"$_" text="$filler"!) } @empty_licenses ;
 
                 }
                 else {
-                    say "Adding dummy license text for license $l for path @paths";
+                    $self->_say( "Adding dummy license text for license $l for path @paths");
                     $datum->{License}{full_license} = $filler;
                 }
             }
 
         }
 
-        $files_obj->fetch_with_id($path_str)->load_data( $datum );
+        eval {
+            $files_obj->fetch_with_id($path_str)->load_data( data => $datum, check =>'yes' );
+        };
+        if ($@) {
+            die "Error: Data extracted from source file is corrupted:\n$@"
+                ."This usually mean that cme or licensecheck (or both)"
+                ."have a bug. You may work-around this issue by adding an override entry in "
+                ."fill.copyright.blanks file. See "
+                ."https://github.com/dod38fr/config-model/wiki/Updating-debian-copyright-file-with-cme "
+                ."for instructions. Last but not least, please file a bug against libconfig-model-dpkg-perl.\n";
+        }
     }
 
     # delete global license without text
@@ -189,7 +273,7 @@ sub update ($self, %args) {
 
     # put back preserved data
     foreach my $old_path (sort keys %preserved_path) {
-        say "Note: preserving entry '$old_path'" ;
+        $self->_say( "Note: preserving entry '$old_path'");
         $files_obj->fetch_with_id($old_path)->load_data( $preserved_path{$old_path} );
     }
 
@@ -198,22 +282,44 @@ sub update ($self, %args) {
         $files_obj->fetch_with_id($deb_path)->load_data( $debian_paths{$deb_path} );
     }
 
-    # read a debian/fix.scanned.copyright file to patch scanned data
-    my $debian = $current_dir->child('debian'); # may be missing in test environment
-    if ($debian->is_dir) {
-        $debian->children(qr/fix\.scanned\.copyright$/);
-        my @fixes = $current_dir->child('debian')->children(qr/fix\.scanned\.copyright$/);
-        say "Note: loading @fixes fixes from copyright fix files" if @fixes;
-        foreach my $fix ( @fixes) {
-            my @l = grep { /[^\s]/ } grep { ! m!^(#|//)!  } $fix->lines_utf8;
-            $self->load( join('',@l) );
-        }
-    }
+    $self->_apply_fix_scan_copyright_file($current_dir) ;
 
     # normalized again after all the modifications
     $self->load("Files:.sort");
 
-    return ''; # improve returned message ?
+    $self->instance->clear_changes; # too many changes to show users
+    $self->notify_change(note => "updated copyright from source file"); # force a save
+
+    my @msgs = (
+        "Please follow the instructions given in ".__PACKAGE__." man page,",
+        "section \"Tweak results\" if some license and copyright entries are wrong.",
+        "Other information, like license text, can be added directly in debian/copyright file ",
+        "and will be merged correctly next time this command is run.",
+        "See also https://github.com/dod38fr/config-model/wiki/Updating-debian-copyright-file-with-cme"
+    );
+
+    return @msgs;
+}
+
+sub _apply_fix_scan_copyright_file ($self, $current_dir) {
+    # read a debian/fix.scanned.copyright file to patch scanned data
+    my $debian = $current_dir->child('debian'); # may be missing in test environment
+    if ($debian->is_dir) {
+        my @fixes = $current_dir->child('debian')->children(qr/fix\.scanned\.copyright$/);
+        $self->_say( "Note: loading @fixes fixes from copyright fix files") if @fixes;
+        foreach my $fix ( @fixes) {
+            my @l = grep { /[^\s]/ } grep { ! m!^(#|//)!  } $fix->lines_utf8;
+            eval { $self->load( join(' ',@l) ); };
+            my $e = $@;
+            if ($e) {
+                my $msg = $e->full_message;
+                Config::Model::Exception::User->throw(
+                    object => $self,
+                    message => "Error while applying fix.scanned.copyright file:\n\t".$msg
+                );
+            }
+        }
+    }
 }
 
 sub _prune_old_dirs ($self, $h, $old_dirs, $path = [] ) {
@@ -227,9 +333,9 @@ sub _prune_old_dirs ($self, $h, $old_dirs, $path = [] ) {
     }
 
     # delete current directory entry
-    my $dir_path = join('/', $path->@*,'*');
+    my $dir_path = join('/', $path->@*,'.');
     if ($old_dirs->{$dir_path}) {
-        say "Removing old entry $dir_path";
+        $self->_say( "Removing old entry $dir_path" );
         delete $old_dirs->{$dir_path};
     }
 }
@@ -237,7 +343,7 @@ sub _prune_old_dirs ($self, $h, $old_dirs, $path = [] ) {
 
 sub fill_global_license ($self, $l, $text) {
 
-    #say "Adding global license $l";
+    #$self->_say( "Adding global license $l");
     # handle the case where license is something like GPL-2 or GPL-3
     my @names = $l =~ / or / ? split / or /, $l : ($l);
 
@@ -295,6 +401,34 @@ Note: this command is experimental.
 
 =head1 Tweak results
 
+Results can be tweaked either by:
+
+=over
+
+=item *
+
+Changing the list of files to scan or ignore. (By default, licensecheck will decide
+which file to scan or not.)
+
+=item *
+
+Specifying information for individual files
+
+=item *
+
+Tweaking the copyright entries created by grouping and coaslescing
+information.
+
+=back
+
+The first 2 ways are described in
+L<Dpkg::Copyright::Scanner/"Selecting or ignoring files to scan">
+and L<Dpkg::Copyright::Scanner/"Filling the blanks">.
+
+The last way is described below:
+
+=head2 Tweak copyright entries
+
 Since the extraction of copyright information from source file is
 based on comments, the result is sometimes lackluster. Your may
 specify instruction to alter or set specific copyright entries in
@@ -405,6 +539,22 @@ Files entries are sorted and the new C<debian/copyright> is generated.
 
 =back
 
+=head1 update ( %args )
+
+Updates data using the output
+L<Dpkg::Copyright::Scanner/"scan_files ( %args )">.
+
+Parameters in C<%args>:
+
+=over
+
+=item quiet
+
+set to 1 to suppress progress messages. Should be used only in tests.
+
+=back
+
+Otherwise, C<%args> is passed to C<scan_files>
 
 =head1 AUTHOR
 
