@@ -5,7 +5,7 @@
     ],
     'class_description' => 'Model of Debian source package files (e.g debian/control, debian/copyright...)',
     'copyright' => [
-      '2010-2015 Dominique Dumont',
+      '2010-2015 Dominique Dumont'
     ],
     'element' => [
       'my_config',
@@ -22,11 +22,40 @@
       },
       'rules',
       {
-        'description' => 'debian/rules is a makefile containing all intructions required to build a debian package.',
+        'description' => 'debian/rules is a makefile containing all instructions required to build a debian package.',
         'summary' => 'package build rules',
         'type' => 'leaf',
         'value_type' => 'string'
       },
+      'scan-copyright-patterns',
+      {
+        'config_class_name' => 'Dpkg::Copyright::ScanPatterns',
+        'description' => 'This parameter is used by "cme update dpkg-copyright". This command scans all source files to get copyright and license information. By default, the decision whether to scan a file or not is left to licensecheck. You can override this behavior using this parameter.
+
+See L<Dpkg::Copyright::Scanner/"electing or ignoring files to scan"> for more details.',
+        'type' => 'node'
+      },
+      'fill-copyright-blanks',
+      {
+        'config_class_name' => 'Dpkg::Copyright::FillBlanks',
+        'description' => 'This parameter is used by "cme update dpkg-copyright command".
+
+Sometimes, upstream coders are not perfect: some source files cannot be parsed correctly or some legal information is missing. A file without copyright and license information is skipped. On the other hand, a file with either copyright or license missing will be used. Unfortunately, this will prevent a correct grouping and merging of copyright entries. Instead of patching upstream source files to fill the blank, you can specify the missing information in a special file.',
+        'summary' => 'Provides missing copyright info for cme update',
+        'type' => 'node'
+      },
+      'fix.scanned.copyright',
+      {
+        'description' => 'Instructions to alter or set specific copyright entries in
+"debian/fix.scanned.copyright" file. Each line of this file
+follows the syntax described in L<Config::Model::Loader>
+to modify copyright information.
+
+See L<Config::Model::Dpkg::Copyright/"Tweak copyright entries"> for more
+details',
+        'type' => 'leaf',
+        'value_type' => 'string'
+      },
       'copyright',
       {
         'config_class_name' => 'Dpkg::Copyright',
