@@ -1,5 +1,18 @@
 [
   {
+    'accept' => [
+      '.*',
+      {
+        'description' => 'Additional user-defined fields
+
+Fields in the main source control information file with names starting X, followed by one or more of the letters BCS and a hyphen -, will be copied to the output files. Only the part of the field name after the hyphen will be used in the output file. Where the letter B is used the field will appear in binary package control files, where the letter S is used in Debian source control files and where C is used in upload control (.changes) files.
+
+For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html>',
+        'summary' => 'User defined field',
+        'type' => 'leaf',
+        'value_type' => 'string'
+      }
+    ],
     'author' => [
       'Dominique Dumont'
     ],
