@@ -1,5 +1,18 @@
 [
   {
+    'accept' => [
+      '.*',
+      {
+        'description' => 'Additional user-defined fields
+
+Fields in the main source control information file with names starting X, followed by one or more of the letters BCS and a hyphen -, will be copied to the output files. Only the part of the field name after the hyphen will be used in the output file. Where the letter B is used the field will appear in binary package control files, where the letter S is used in Debian source control files and where C is used in upload control (.changes) files.
+
+For details, see L<section 5.7 of Debian policy|https://www.debian.org/doc/debian-policy/ch-controlfields.html>',
+        'summary' => 'User defined field',
+        'type' => 'leaf',
+        'value_type' => 'string'
+      }
+    ],
     'author' => [
       'Dominique Dumont'
     ],
@@ -267,16 +280,16 @@ Note that packages not wanted during "clean" phase must be declared in "Build-Co
       },
       'Standards-Version',
       {
-        'default' => '3.9.6',
+        'default' => '3.9.7',
         'description' => 'This field indicates the Debian policy version number this package complies to',
         'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
         'summary' => 'Debian policy version number this package complies to',
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '3\\.9\\.6' => {
+          '3\\.9\\.7' => {
             'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Current standards version is 3.9.6'
+            'msg' => 'Current standards version is 3.9.7'
           }
         }
       },
@@ -375,8 +388,8 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       {
         'compute' => {
           'allow_override' => '1',
-          'formula' => '  $maintainer =~ /(pkg-perl)/                        ? "git://anonscm.debian.org/$1/packages/$pkgname.git"
-: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/  ? "git://anonscm.debian.org/$1/$pkgname.git"
+          'formula' => '  $maintainer =~ /(pkg-perl)/                        ? "https://anonscm.debian.org/git/$1/packages/$pkgname.git"
+: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/  ? "https://anonscm.debian.org/git/$1/$pkgname.git"
 :                                                    \'\' ;',
           'use_eval' => '1',
           'variables' => {
@@ -391,15 +404,19 @@ The information is meant to be useful for a user knowledgeable in the given Vers
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_if_match' => {
+          '^(git|http)://' => {
+            'fix' => 's/^(git|http):/https:/;',
+            'msg' => 'An unencrypted transport protocol is used for this URI. It is recommended to use a secure transport such as HTTPS for anonymous read-only access.'
+          },
           'debian.org/~' => {
             'msg' => 'URL contains deprecated \'~\' path to user'
           }
         },
         'warn_unless' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^http://anonscm.debian.org/git/(?!git/)} or m{^git://anonscm.debian.org/(?!git/)} ;',
-            'fix' => 's!http://[\\w\\.-]+/(git/)*!http://anonscm.debian.org/git/!;
-s!git://[\\w\\.-]+/(git/)?!git://anonscm.debian.org/!;',
+            'code' => '!defined $_ or ! /debian.org/ or m{^https://anonscm.debian.org/git/(?!git/)};',
+            'fix' => 's!http://[\\w\\.-]+/(git/)*!https://anonscm.debian.org/git/!;
+s!git://[\\w\\.-]+/(git/)?!https://anonscm.debian.org/git/!;',
             'msg' => 'URL to debian system is not the recommended one'
           }
         }
