@@ -130,7 +130,13 @@ See L<files pattern documentation|https://www.debian.org/doc/packaging-manuals/c
       {
         'description' => 'White space separated list of file patterns to exclude from the package. This field is only used by L<uscan>. Example: C<*/Makefile.in aclocal.m4>. See also L<UscanEnhancements|https://wiki.debian.org/UscanEnhancements> and the L<files pattern documentation|https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/#files-field>.',
         'type' => 'leaf',
-        'value_type' => 'string'
+        'value_type' => 'string',
+        'warn_if_match' => {
+          '\\/(\\s|$)' => {
+            'fix' => 's!/(?=\\s|$)!!g;',
+            'msg' => 'directory entries should not have a trailing slash'
+          }
+        }
       },
       'Global-License',
       {
