@@ -93,6 +93,30 @@ license: abbrev exception(?)
         },
         'type' => 'leaf',
         'value_type' => 'uniline',
+        'warn_if_match' => {
+          '(^|\\s)BSD-?[234](\\s|$)' => {
+            'fix' => '# need to test if target exists before moving element
+my $old = $_;
+s/BSD-?(\\d)/BSD-$1-clause/;
+my $lic = $self->grab(\'- - - License\');
+my $text = $self->grab_value(\'- full_license\');
+$lic->move($old,$_) unless $text or $lic->defined($_);
+',
+            'msg' => 'Please use BSD-x-clause name, like BSD-3-clause'
+          },
+          '(^|\\s)MIT(\\s|$)' => {
+            'fix' => '# need to test if target exists before moving element
+my $lic = $self->grab(\'- - - License\');
+my $text = $self->grab_value(\'- full_license\');
+$lic->move($_,\'Expat\') unless $text or $lic->defined(\'Expat\') ;
+$_ = \'Expat\';
+',
+            'msg' => 'There are many versions of the MIT license. Please use Expat instead, when it matches. See L<Debian copyright format|https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/#license-specification> and L<wikipedia|https://en.wikipedia.org/wiki/MIT_License#Various_versions>for details.'
+          },
+          'UNKNOWN' => {
+            'msg' => 'Unknown license: please add correct value or remove the File entry.'
+          }
+        },
         'warp' => {
           'rules' => [
             '&location !~ /Global/',
