@@ -31,9 +31,15 @@ if (defined $lic and $lic) {
    eval {
        $text = Software::LicenseUtils->new_from_short_name($h)->debian_text ;
    } ;
-
+   if ($text) {
+       # need to cleanup text to mimic cleanup done when copyright
+       # data is read from file
+       chomp($text);
+       # work-around a bug in lgpl license text summary... my bad :-/
+       $text =~ s!^\\.!!mg;
+   }
 # FIXME: find a way to warn user if a license is unknown only when
-# text is not set by another mean...
+# text is not set by another mean... may loop bad if not careful
 #   if ($@ and ! $self->value_object->{data}) {
 #       print "Cannot find license text for $lic\\n" ;
 #   }
@@ -45,7 +51,12 @@ $text;',
         },
         'description' => 'Full license text.',
         'type' => 'leaf',
-        'value_type' => 'string'
+        'value_type' => 'string',
+        'warn_if_match' => {
+          'fill license' => {
+            'msg' => 'License contains copyright scanner boilerplate. Please update this field with the actual license text'
+          }
+        }
       }
     ],
     'license' => 'LGPL2',
