@@ -59,6 +59,17 @@ The vendor name is explicitly encoded in the field name so that vendors can shar
 
 To get a vendor bug (like Bug-Foo) in the graphical editor, right-click on the patch name, enter "C<Bug-Foo>" (or any other value) in the "C<accept:>" entry and hit "Return". A new element will be created that
 you can fill like the C<Bug> field.',
+        'summary' => 'URL for related upstream bug(s)',
+        'type' => 'list'
+      },
+      'Bug-Debian',
+      {
+        'cargo' => {
+          'type' => 'leaf',
+          'value_type' => 'uniline'
+        },
+        'description' => 'This field contains one URL pointing to the related bug (possibly fixed by the patch). The Bug-Debian field is reserved for the bug URL in Debian BTS. Those fields can be used multiple times if several bugs are concerned.',
+        'summary' => 'URL for related bug in Debian BTS',
         'type' => 'list'
       },
       'Forwarded',
@@ -84,7 +95,7 @@ If the field is missing, its implicit value is "yes" if the "Bug" field is prese
       {
         'description' => 'This field should document the origin of the patch. In most cases, it should be a simple URL. For patches backported/taken from upstream, it should point into the upstream VCS web interface when possible, otherwise it can simply list the relevant commit identifier (it should be prefixed with "commit:" in that case). For other cases, one should simply indicate the URL where the patch was taken from (mailing list archives, distribution bugtrackers, etc.) when possible.
 
-The field can be optionaly prefixed with a single keyword followed by a comma and a space to categorize the origin. The allowed keywords are "upstream" (in the case of a patch cherry-picked from the upstream VCS), "backport" (in the case of an upstream patch that had to be modified to apply on the current version), "vendor" for a patch created by Debian or another distribution vendor, or "other" for all other kind of patches.
+The field can be optionally prefixed with a single keyword followed by a comma and a space to categorize the origin. The allowed keywords are "upstream" (in the case of a patch cherry-picked from the upstream VCS), "backport" (in the case of an upstream patch that had to be modified to apply on the current version), "vendor" for a patch created by Debian or another distribution vendor, or "other" for all other kind of patches.
 
 In general, a user-created patch grabbed in a BTS should be categorized as "other". When copying a patch from another vendor, the meta-information (and hence this field) should be kept if present, or created if necessary with a "vendor" origin.
 
