@@ -8,6 +8,8 @@ use IO::Pipe;
 use Exporter::Lite;
 use Array::IntSpan;
 use Path::Tiny;
+use Carp;
+use YAML::Any;
 
 use feature qw/postderef signatures/;
 no warnings qw/experimental::postderef experimental::signatures/;
@@ -61,11 +63,12 @@ sub print_copyright ( %args ) {
         my ($id, @paths) = $p->@*;
         my ($c,$l) = $copyrights_by_id->[$id]->@*;
 
-        next if $c eq 'no-info-found';
+        next if $id == 0;
 
         # don't print directory info covered by same info in directory above
         next if $paths[0] =~ /\.$/;
 
+        $c = "UNKNOWN" unless $c;
         push @out,
             "Files: ", join($whitespace_list_delimiter, @paths )."\n",
             "Copyright: $c\n",
@@ -81,10 +84,79 @@ sub print_copyright ( %args ) {
     }
 }
 
+my $quiet;
+
+sub _warn ($msg) {
+    warn $msg unless $quiet;
+}
+
+my %default ;
+# from licensecheck.pl
+$default{ignore}= qr!
+# Ignore general backup files
+~$|
+# Ignore emacs recovery files
+(?:^|/)\.#|
+# Ignore vi swap files
+(?:^|/)\..*\.swp$|
+# Ignore baz-style junk files or directories
+(?:^|/),,.*(?:$|/.*$)|
+# File-names that should be ignored (never directories)
+(?:^|/)(?:DEADJOE|\.cvsignore|\.arch-inventory|\.bzrignore|\.gitignore)$|
+# File or directory names that should be ignored
+(?:^|/)(?:CVS|RCS|\.pc|\.deps|\{arch\}|\.arch-ids|\.svn|\.hg|_darcs|\.git|
+\.shelf|_MTN|\.bzr(?:\.backup|tags)?)(?:$|/.*$)
+!x;
+
+# also from licensecheck
+$default{check} =
+    qr!
+    \.(                          # search for file suffix
+        c(c|pp|xx)?              # c and c++
+       |h(h|pp|xx)?              # header files for c and c++
+       |S
+       |css|less                 # HTML css and similar
+       |f(77|90)?
+       |go
+       |groovy
+       |lisp
+       |scala
+       |clj
+       |p(l|m)?6?|t|xs|pod6?     # perl5 or perl6
+       |sh
+       |php
+       |py(|x)
+       |rb
+       |java
+       |js
+       |vala
+       |el
+       |sc(i|e)
+       |cs
+       |pas
+       |inc
+       |dtd|xsl
+       |mod
+       |m
+       |md|markdown
+       |tex
+       |mli?
+       |(c|l)?hs
+     )
+    $
+   !x;
+
+# cleanup the regexp
+map { s/#.*\n//g;  s/\n//g; } values %default;
+
 # option to skip UNKNOWN ?
 # load a file to override some entries ?
 sub scan_files ( %args ) {
 
+    $quiet = $args{quiet} // 0;
+
+    my $current_dir = $args{from_dir} || path('.');
+
     my @lines ;
     if (my $file = $ENV{COPYRIGHT_SCANNER_INPUT}) {
         @lines = path($file)->lines_utf8 ; # for tests
@@ -93,40 +165,66 @@ sub scan_files ( %args ) {
         @lines = $args{in}->lines_utf8; # for other tests
     }
     else {
-        foreach my $opts ( ('',q! -c '(?i:readme|license|copying).*'!)) {
+        my @runs = (['--skipped'], [qw!-c (?i:readme|license|copying).*!]);
+
+        my $debian = $current_dir->child('debian');
+        my $scan_patterns = $debian->child("copyright-scan-patterns.yml");
+
+        if ($debian->is_dir and $scan_patterns->is_file) {
+            my $yaml = $scan_patterns->slurp_utf8;
+            # { check => { suffixes => [ js pl ], pattern => '[A-Z]*'}, ignore => { suffixes => [ jpg png ], pattern => 'foo.*'} }
+            my $scan_data = Load $yaml;
+            my @opts = ();
+            foreach my $what (qw/check ignore/) {
+                my $data = $scan_data->{$what} or next;
+                my $reg = join( '|' , (map { '\.'.$_.'$'} @{$data->{suffixes} || []}), @{ $data->{pattern} || []}, $default{$what});
+                push @opts, '--skipped', "--$what=$reg";
+            }
+            @runs = \@opts ;
+        }
+
+        foreach my $opts ( @runs ) {
             my $pipe = IO::Pipe->new();
-            $pipe->reader("licensecheck --copyright -m -r $opts .");
+            my @cmd = (qw/licensecheck --encoding utf8 --copyright --machine --recursive/,  @$opts, '.');
+            $pipe->reader(@cmd);
             binmode($pipe, ":encoding(UTF-8)");
             push @lines, $pipe->getlines;
             $pipe->close;
         }
     }
 
+    my $fill_blank_data = __load_fill_blank_data($current_dir);
+
     my %copyrights ;
     my $files = {};
-    my $id = 0;
+    my $id = 1;
+    my @no_info_list;
 
     foreach my $line (sort @lines) {
         chomp $line;
         # say "found: $line";
         my ($f,$l,$c) = split /\t/, $line; 
         $f =~ s!\./!!;
+        next if $f =~ m!debian/(copyright|changelog)$!; # too confusing
+        next if $files->{$f}; # file already parsed
 
         $l =~ s/([*?\\])/\\$1/g;
-        $l =~ s/\s*\(unversioned\/unknown version\)//;
-        $l =~ s/\s*\(with incorrect FSF address\)//;
-        $l =~ s/(\w+)\s+\(v([^)]+) or v([^)]+)\)/uc($1)."-$2 or ".uc($1)."-$3"/e;
-        $l =~ s/\s+\(v([^)]+) or later\)/-$1+/;
-        $l =~ s/\s+\(v([^)]+)\)/-$1/;
-        $l =~ s/^\s*(GENERATED FILE)/UNKNOWN/;
-        $l =~ s/\s+(GENERATED FILE)//;
-        $l =~ s/\bzlib\/libpng\b/Zlib/;
-        $l =~ s/\bMIT\/X11 \(BSD like\)/Expat/;
-        $l =~ s/\bBSD \((\d) clause\)/BSD-$1-clause/;
-        $l =~ s/\bpublic domain\b/public-domain/i;
+        $l =~ s/\s*\(unversioned\/unknown version\)//g;
+        $l =~ s/\s*\(with incorrect FSF address\)//g;
+        $l =~ s/(\w+)\s+\(v([^)]+) or v([^)]+)\)/uc($1)."-$2 or ".uc($1)."-$3"/eg;
+        $l =~ s/\s+\(v([^)]+) or later\)/-$1+/g;
+        $l =~ s/\s+\(v([^)]+)\)/-$1/g;
+        $l =~ s/^\s*(GENERATED FILE)/UNKNOWN/g;
+        $l =~ s/\s+(GENERATED FILE)//g;
+        $l =~ s/\bzlib\/libpng\b/Zlib/g;
+        $l =~ s/\bMIT\/X11 \(BSD like\)/Expat/g;
+        $l =~ s/\bBSD \((\d) clause\)/BSD-$1-clause/g;
+        $l =~ s/\bpublic domain\b/public-domain/ig;
 
-        # this is very fragile. may need to change license-check to output license keyword
-        $l =~ s/ / or /g unless $l =~ /\bor\b/;
+        # deduplicate license keywords and add 'or' keyword where missing
+        # this is fragile. may need to change license-check to output license keyword
+        my %tmp_l = map { ( $_ => 1) ;} grep { $_ ne 'or' } split(/ /,$l);
+        $l = join(' or ', sort keys %tmp_l) ;
 
         $c =~ s/'//g;
         $c =~ s/^&copy;\s*//;
@@ -137,16 +235,61 @@ sub scan_files ( %args ) {
         $c =~ s/(\\n)*all\s+rights?\s+reserved\.?(\\n)*\s*//gi; # yes there are literal \n
         $c = 'no-info-found' if $c =~ /^\*No/;
         $c =~ s/\(r\)//g;
-        $c =~ s!^[\s,/*]|[\s,/*-]+$!!g;
+        $c =~ s!^[\s,/*]|[\s,#/*-]+$!!g;
         $c =~ s/--/-/g;
         $c =~ s!\s+\*/\s+! !;
 
         $c = __pack_copyright($c);
 
-        next if $l =~ /unknown/i and $c =~ /no-info-found/i;
+        # this data overrides what's found in current files. This is done before
+        # the code that merge and coaslesce entries
+        my $fill_blank = __get_fill_blank($fill_blank_data, $f);
 
-        #say "Storing '$f' : '$c' '$l'";
-        $files->{$f} = $copyrights{$c}{$l} //= $id++;
+        next if $fill_blank->{skip};
+
+        if ( $c =~ /no-info-found/ and $fill_blank->{copyright} ) {
+            $c = $fill_blank->{copyright};
+        }
+        if ($fill_blank->{'override-copyright'}) {
+            _warn "Overriding path $f copyright info\n";
+            $c = $fill_blank->{'override-copyright'};
+        }
+        if ( $l =~/unknown/i and $fill_blank->{license} ) {
+            $l = $fill_blank->{license};
+        }
+        if ($fill_blank->{'override-license'}) {
+            _warn "Overriding path $f license info\n";
+            $l = $fill_blank->{'override-license'};
+        }
+
+        my @no_info_found;
+        if ( $c =~ /no-info-found/ ) {
+            push @no_info_found, 'copyright';
+        }
+        if ( $l =~/unknown/i ) {
+            push @no_info_found, 'license';
+        }
+
+        push @no_info_list , [$f , @no_info_found ] if @no_info_found;
+
+        my $has_info = @no_info_found < 2 ? 1 : 0;
+        $files->{$f} = $copyrights{$c}{$l} //= ($has_info ? $id++ : 0);
+        # say "Storing '$f' : '$c' '$l' has_info: $has_info id ".$files->{$f};
+    }
+
+    if (@no_info_list) {
+        my $msg= "The following paths are missing information:\n";
+        map {my ($p,@i) = $_->@*;
+             $msg .= "- $p: missing ".join(' and ', @i)."\n";
+         } @no_info_list;
+        $msg .= "You may want to add a line in debian/fill.copyright.blanks.yml\n\n";
+        _warn $msg;
+    }
+
+                my @notused = grep { ! $fill_blank_data->{$_}{used} and $_; } sort keys %$fill_blank_data ;
+    if (@notused) {
+        _warn "Warning: the following entries from fill.copyright.blanks.yml were not used\n- '"
+            .join("'\n- '",@notused)."'\n";
     }
 
     my @copyrights_by_id ;
@@ -157,7 +300,7 @@ sub scan_files ( %args ) {
         }
     }
 
-    say "No copyright information found" unless keys %$files;
+    warn "No copyright information found" unless keys %$files;
 
     my $merged_c_info = __squash_copyrights_years (\@copyrights_by_id) ;
 
@@ -211,12 +354,12 @@ sub __pack_copyright ($r) {
                 $span->set_range_as_string($year, $owner);
             };
             if ($@) {
-                say "Invalid year range in copyright: $r";
+                warn "Invalid year range in copyright: $r";
                 return $r;
             }
         }
         $span->consolidate();
-        push @res, $span->get_range_list. ', '. $owner;
+        push @res, $span->get_range_list. ($owner ? ', '. $owner : '');
     }
     return join("\n ",reverse sort @res);
 }
@@ -261,7 +404,7 @@ sub __pack_dir ($h, $pack, @path) {
 sub __squash_copyrights_years ($copyrights_by_id) {
 
     my %id_year_by_same_owner_license;
-    for (my $id = 0; $id < $copyrights_by_id->@* ; $id++ ) {
+    for (my $id = 1; $id < $copyrights_by_id->@* ; $id++ ) {
         my ($c,$l) = $copyrights_by_id->[$id]->@* ;
         #say "id $id: c $c l $l";
         my @owners ;
@@ -332,7 +475,7 @@ sub __coalesce_copyright_years($entries, $owners) {
                 $span->set_range_as_string($years[$i], 1);
             };
             if ($@) {
-                say "Invalid year range: ",$years[$i];
+                warn "Invalid year range: ",$years[$i];
                 return ();
             }
         }
@@ -349,7 +492,7 @@ sub __coalesce_copyright_years($entries, $owners) {
 
 # $h is a tree of hash matching the directory structure. Each leaf is a
 # copyright id. Each key is a file name in a directory (not the full path)
-sub __squash ($h) {
+sub __squash ($h, $p = '') {
     my %count ;
 
     # find main license info found in LICENCE or COPYING or README
@@ -359,8 +502,9 @@ sub __squash ($h) {
         foreach my $name (sort keys %$h) {
             if ($name =~ $re) {
                 my $id = delete $h->{$name};
-                #say "del global lic info $name with ".Dumper($id);
-                # using 1 means that info from this file is easy to override
+                next unless $id; # skip files without info
+                # say "del global lic info $p/$name with $id";
+                # using 1 means that info from this file is not easy to override
                 $count{$id} = 1;
             };
         }
@@ -373,12 +517,13 @@ sub __squash ($h) {
         if (ref($item)) {
             # squash may return a plain id, or a hash with '*' => id ,
             # or a non squashable hash
-            $h->{$name} = __squash($item);
+            $h->{$name} = __squash($item, $p.'/'.$name);
         }
         my $id = (ref($item) and defined $item->{'*'}) ? $item->{'*'} : $item ;
 
         # do not count non squashable hashes (i.e. there's no main (c) info)
-        if (not ref ($id)) {
+        # do not count ids containing no information (id 0)
+        if (not ref ($id) and $id != 0) {
             $count{$id}//=0;
             $count{$id} ++;
         }
@@ -399,28 +544,74 @@ sub __squash ($h) {
 
     # all files associated to the most used (c) info are deleted to
     # be represented by '*' entry
-    foreach my $name (sort keys %$h) {
-        my $item = $h->{$name};
-        if (ref($item) and defined $item->{'*'} and $item->{'*'} == $main_license_id) {
-            # rename item/* to item/. when covered by ./*
-            # this is a "weak" directory info which is handled specially
-            $item->{'.'} = delete $item->{'*'};
-        }
-        if (not ref ($item)) {
-            # delete file that is represented by '*' entry
-            delete $h->{$name} if $item == $main_license_id;
+    if (defined $main_license_id) {
+        foreach my $name (sort keys %$h) {
+            my $item = $h->{$name};
+            if (ref($item) and defined $item->{'*'} and $item->{'*'} == $main_license_id) {
+                # rename item/* to item/. when covered by ./*
+                # this is a "weak" directory info which is handled specially
+                $item->{'.'} = delete $item->{'*'};
+            }
+            if (not ref ($item)) {
+                # delete file that is represented by '*' entry
+                delete $h->{$name} if $item == $main_license_id;
+            }
         }
+
+        # here's the '*' file representing the most used (c) info
+        $h->{'*'} //= $main_license_id;
     }
-    # here's the '*' file representing the most used (c) info
-    $h->{'*'} //= $main_license_id if defined $main_license_id;
 
     return $h;
 }
 
+sub __load_fill_blank_data ($current_dir) {
+    my %fill_blanks ;
+    my $debian = $current_dir->child('debian'); # may be missing in test environment
+
+    if ($debian->is_dir) {
+        my @fills = $debian->children(qr/fill\.copyright\.blanks\.yml$/);
+
+        warn "Note: loading @fills fixes" if @fills and not $quiet;
+        foreach my $file ( @fills) {
+            my $yaml = $file->slurp_utf8;
+            my $data = Load $yaml;
+            foreach my $path (sort keys %$data) {
+                if ($fill_blanks{$path}) {
+                    warn "Warning: skipping duplicated fill blank path $path from file $file";
+                }
+                else {
+                    $fill_blanks{$path} = $data->{$path};
+                }
+
+                foreach my $k (keys $fill_blanks{$path}->%*) {
+                    die "Error in file $file: Unexpected key '$k' in path '$path'\n"
+                        unless $k =~/^(comment|skip|(override-)?(license|copyright))$/;
+                }
+            }
+        }
+    }
+
+    return \%fill_blanks;
+}
+
+sub __get_fill_blank ($fbd,$file) {
+
+    foreach my $path (reverse sort keys %$fbd) {
+        if ($file =~ m(^$path)) {
+            $fbd->{$path}{used} = 1;
+            return $fbd->{$path};
+        }
+    }
+    return {};
+}
+
 1;
 
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
  Dpkg::Copyright::Scanner - Scan files to provide copyright data
@@ -443,13 +634,105 @@ license information. Information are packed in a way to ease review and
 maintenance. Files information is grouped with wildcards ('*') to reduce
 the list of files.
 
+=head1 Selecting or ignoring files to scan
+
+By default, the decision whether to scan a file or not is left to L<licensecheck>.
+
+You can change this behavior in file
+C<debian/copyright-scan-patterns.yml>. This YAML file can
+contain a list of suffixes or patterns to scan or to ignore that are added to licensecheck's list. Any file
+that is not scanned or ignored will be shown as "skipped".
+
+The file must have the following structure (all fields are optional
+and order does not matter):
+
+ ---
+ check :
+   suffixes :
+     - PL       # check .PL$
+     - asm
+   pattern:
+     - /README$
+ ignore :
+   suffixes :
+     - yml
+   pattern :
+     - /t/
+     - /models/
+     - /debian/
+     - /Changes
+
+Do not specify the dot with the suffixes. This will be added by the scanner.
+
+=head1 Filling the blanks
+
+Sometimes, upstream coders are not perfect: some source files cannot
+be parsed correctly or some legal information is missing.
+
+All scanned files, even without copyright or license will be used. A
+warning will be shown for each file with missing information.
+
+Instead of patching upstream source files to fill the blank, you can
+specify the missing information in a special file. This file is
+C<debian/fill.copyright.blanks.yml>. It should contain a "mapping"
+YAML structure (i.e. a hash), where the key is a Perl pattern used to
+match a path. 
+
+If the source of the package contains a lot of files without legal
+information, you may need to specify there information for a whole
+directory (See the C</src> dir in the example below).
+
+For instance:
+
+ ---
+ debian:
+   copyright: 2015, Marcel
+   license: Expat
+ src/:
+   copyright: 2016. Joe
+   license: Expat
+ share/pkgs/openSUSE/systemd/onedsetup:
+   copyright: 2015, Marcel
+ share/vendor/ruby/gems/rbvmomi/lib/rbvmomi.*\.rb:
+   license: Expat
+ .*/NOTICE:
+   skip: 1
+ share/websockify/:
+   license: LGPL-2
+ src/sunstone/:
+   license: Apache-2.0
+ src/garbled/:
+   'override-copyright': 2016 Marcel Mézigue
+
+Patterns are matched from the beginning a
+path. I.e. C<share/websockify/> pattern will match
+C<share/websockify/foo.rb> but will not match
+C<web/share/websockify/foo.rb>.
+
+Patterns are tried in reversed sorted order. I.e. the data attached to
+more specific path (e.g. C<3rdparty/foo/blah.c>) are applied before
+more generic patterns (e.g. C<3rdparty/foo/>
+
+The C<license> key must contain a license short name as returned by
+C<license_check>.
+
+When C<skip> is true, the file is skipped like a file without any
+information.
+
+The C<override-copyright> and C<override-license> keys can be used to
+ignore the copyright information coming from the source and provide
+the correct information. Use this as last resort for instance when the
+encoding of the owner is not ascii or utf-8 or when the license data
+is corrupted. Note that a warning will be shown each time an override
+key is used.
+
 =head1 METHODS
 
 =head2 print_copyright
 
 Print copyright information on STDOUT like L<scan-copyrights>.
 
-=head2 scan_files
+=head2 scan_files ( %args )
 
 Return a data structure with copyright and license information.
 
@@ -487,6 +770,17 @@ Example:
   ],
  ]
 
+Parameters in C<%args>:
+
+=over
+
+=item quiet
+
+set to 1 to suppress progress messages. Should be used only in tests.
+
+=back
+
+
 =head1 Encoding
 
 The output of L<licensecheck> is expected to be utf-8. Which means
@@ -500,6 +794,27 @@ Extracting license and copyright data from unstructured comments is not reliable
 User must check manually the files when no copyright info is found or when the
 license is unknown.
 
+Source files are assumed to be utf8 (or ascii). Using files with other encoding
+will lead to garbled names of copyright owner. In this case, you can:
+
+=over
+
+=item *
+
+Path source files to use utf-8 encoding.
+
+=item *
+
+Use the "fill copyright blank" mechanism described above with
+C<copyright-override> to provide an owner name with the correct
+encoding.
+
+=item *
+
+File a bug against licensecheck of devscript package to find a better solution.
+
+=back
+
 =head1 SEE ALSO
 
 L<licensecheck>, C<licensecheck2dep5> from C<cdbs> package
