@@ -25,10 +25,13 @@ providing the following file:
             'source Build-Depends-Indep:5', "libpath-class-perl",
             'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000)", # fixed
             'source Build-Depends-Indep:7', "udev [linux-any] | makedev [linux-any]",
+            'source X-Comment' => qr/Debian #810023/,
+            'binary:libdist-zilla-plugins-cjm-perl X-Comment' => qr/Debian #810023/,
+
             'binary:libdist-zilla-plugins-cjm-perl Depends:0',
             '${misc:Depends}',
             'source Vcs-Browser' ,'https://anonscm.debian.org/cgit/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
-            'source Vcs-Git', 'git://anonscm.debian.org/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
+            'source Vcs-Git', 'https://anonscm.debian.org/git/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
         },
         load_warnings => [ qr/dependency/, qr/dual life/, (qr/dependency/) x 2, 
                           qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
@@ -110,7 +113,7 @@ providing the following file:
     },
     {
         name => 'libpango-perl',
-        load_warnings => [ ( qr/Warning/) x 3 ],
+        load_warnings => [ ( qr/Warning/) x 4 ],
         verify_annotation => {
             'source Build-Depends' => "do NOT add libgtk2-perl to build-deps (see bug #554704)",
             'source Maintainer'    => "what a fine\nteam this one is",
@@ -120,31 +123,32 @@ providing the following file:
     },
     {
         name => 'libwx-scintilla-perl',
-        load_warnings => [ ( qr/Warning/) x 4 ],
+        load_warnings => [ ( qr/Warning/) x 5 ],
         apply_fix => 1,
     },
     {
         # test for #683861
         name => 'libmodule-metadata-perl',
-        load_warnings => [ ( qr/Warning/) x 4 ],
+        load_warnings => [ ( qr/Warning/) x 5 ],
         apply_fix => 1,
     },
     {
         # test for #682730
         name => 'libclass-meta-perl',
-        load_warnings => [ ( qr/Vcs-Git/) ],
+        load_warnings => [ ( qr/Vcs-Git/) x 2 ],
          check => { 'source Build-Depends-Indep:1' => 'libclass-isa-perl | perl (<< 5.10.1-13)' },
         apply_fix => 1,
     },
     {
         # test for #692849, must not warn about missing libfoo dependency
         name => 'dbg-dep',
-        load_warnings => [ qr/DM-Upload/ ],
+        load_warnings => [ ( qr/Vcs-Git/) x 2, qr/DM-Upload/ ],
     },
     {
         # test for #696768, Built-Using field
         name => 'built-using',
-        load_warnings => [ qr/DM-Upload/ ],
+        load_warnings => [ ( qr/Vcs-Git/) x 2, qr/DM-Upload/ ],
+        apply_fix => 1,
     },
     {
         # test for #719753, XS-Autobuild field
@@ -153,6 +157,7 @@ providing the following file:
             'source Section' => 'non-free/libs',
             'source XS-Autobuild' => 'yes',
         },
+        load_warnings => [ ( qr/Vcs-Git/) x 2 ],
     },
     {
         # test for #713053,  XS-Ruby-Versions and XB-Ruby-Versions fields
