@@ -51,7 +51,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
 
     # the empty license will default to 'other'
     { # t3
-        load_warnings => [ (qr/deprecated/) x 3 ],
+        load_warnings => [ (qr/deprecated/) x 3, qr/use Expat/ ],
 
         check => {
             'Comment' => "\nHeader comment 1/2\nHeader comment 2/2",
@@ -95,24 +95,26 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
     },
     { # t7
         # example from CANDIDATE DEP-5 spec (nb 7)
-        load_warnings => [ (qr/Adding/) x 1 , qr/Format does not match/ ],
+        load_warnings => [ (qr/Adding/) x 1 , qr/Format does not match/,
+                       qr/trailing slash/],
         load_check => 'skip',
         apply_fix => 1,
         check => { 
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
             'Files:"*" Copyright' => 'Copyright 1998 John Doe <jdoe@example.com>',
             'Files:"debian/*" License short_name' => 'other',
+            'Files-Excluded' => '*.jar 3rdparty/libtommath 3rdparty/stuff',
         },
     },
     {
         # test nb 8
-        load_warnings => [ qr/Format does not match/ ],
+        load_warnings => [ qr/Format does not match/, qr/many versions/ ],
         apply_fix => 1,
         check => { 
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
             'Files:"*" Copyright' => "2008, John Doe <jdoe\@example.com>\n2007, Jane Smith <jsmith\@example.org>\n2007, Joe Average <joe\@example.org>\n2007, J. Random User <jr\@users.example.com>",
-            },
         },
+    },
     {
         load_warnings => [ qr/Format does not match/ ,qr/should not match/ ],
         apply_fix => 1,
@@ -124,7 +126,7 @@ $skip = ( $@ or not -r '/etc/debian_version') ? 1 : 0 ;
         },
     },
     { # t10
-        load_warnings => [ (qr/deprecated/) x 2 ],
+        load_warnings => [ (qr/UK spelling/) x 4, (qr/deprecated/) x 2 ],
 
         check => { 
             Format => "https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/", 
@@ -169,9 +171,9 @@ and Lesser General Public License version 2.1 can be found respectively in
 found in ‘/usr/share/common-licenses/Artistic’, and the complete text of
 the latest version of the GNU General Public License version 1 can be found
 in ‘/usr/share/common-licenses/GPL-1’.",
-            'Files:"lib/Bio/Graphics/Glyph/rndrect.pm 
+            'Files:"lib/Bio/Graphics/Glyph/rndrect.pm
       lib/Bio/Graphics/Glyph/splice_site.pm
- lib/Bio/Graphics/Glyph/extending_arrow.pm" License short_name' => 'Perl',
+        lib/Bio/Graphics/Glyph/extending_arrow.pm" License short_name' => 'Perl',
             'Files:"lib/Bio/Graphics/FeatureDir.pm lib/Bio/Graphics/Glyph/pairplot.pm lib/Bio/Graphics/Glyph/generic.pm" License short_name' => "GPL-1+ or Artistic-2.0",
             'Files:lib/Bio/Graphics/Layout.pm License short_name' => "LGPL-2.1+ or Artistic-2.0",
     } ,
@@ -205,8 +207,13 @@ in ‘/usr/share/common-licenses/GPL-1’.",
     },
     {
         name => 'oar',
-        'File:"sources/extra/orpheus/modules/lua-signal/lsignal.c" License short_name'
-            => 'MIT/X11'
+        load_warnings => [ qr/use Expat/ ],
+        no_warnings => 1,
+
+        check => {
+            'Files:"sources/extra/orpheus/modules/lua-signal/lsignal.c" License short_name'
+            => 'MIT'
+        }
     },
     {
         # Debian bug #721832
@@ -240,7 +247,7 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         name => 'file-instead-of-files' ,
 
         # warning brought by fix of Debian #789568
-        load_warnings => [ qr/confusingly close/ ],
+        load_warnings => [ qr/section 'File' is converted in 'Files'/ ],
 
         check => {
             "Files:debian/patches/half_code_pod_errors.patch Copyright" =>
@@ -259,7 +266,8 @@ in ‘/usr/share/common-licenses/GPL-1’.",
 
     {
         name => 'update-from-scratch',
-        update => { in => path('t/scanner/examples/pan.in') },
+        update => { in => path('t/scanner/examples/pan.in') , quiet => 1 },
+        no_warnings => 1,
         check => {
             "License:GPL-2 text" => {value => undef, mode => 'custom'},
             "License:GPL-2 text" => qr/GNU/,
@@ -272,7 +280,8 @@ in ‘/usr/share/common-licenses/GPL-1’.",
 
     {
         name => 'moarvm-from-scratch',
-        update => { in => path('t/scanner/examples/moarvm.in') },
+        update => { in => path('t/scanner/examples/moarvm.in'), quiet => 1 },
+        no_warnings => 1,
         check => {
             'License:ISC text' => qr/Please fill/,
             'License:BSD-2-clause text' => qr/Please fill/,
@@ -286,6 +295,31 @@ in ‘/usr/share/common-licenses/GPL-1’.",
         },
     },
 
+    { # Debian bug  #797321
+        name => 'warn-MIT',
+        load_warnings => [ (qr/many versions of the MIT license/) x 2 ],
+        apply_fix => 1,
+        check => {
+            "License:Expat text" => 'yada',
+            "License:MITA text" => 'yada',
+            'Files:"*" License short_name' => 'Expat',
+            'Files:"a/*" License short_name' => 'MITA',
+        }
+    },
+    { # Debian bug  #797322
+        name => 'warn-BSD',
+        load_warnings => [ (qr/Please use BSD-x-clause/) x 3 ],
+        apply_fix => 1,
+        check => {
+          'Files:"*" License short_name' => 'BSD-2-clause',
+          'Files:"a/*" License short_name' => 'my-BSD-3',
+          'Files:"b/*" License short_name' => 'BSD-3-clause',
+          'Files:"c/*" License short_name' => 'BSD-3-clause',
+          'License:BSD-2-clause text' => 'yada',
+          'License:BSD-3-clause text' => 'yada',
+          'License:BSD-like text' => 'yada',
+        }
+    },
 );
 
 1;
