@@ -11,12 +11,15 @@ eval { require AptPkg::Config; };
 $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
 
 @tests = (
-    { 
+    {
         name => 'libperl5i' ,
         config_file => $conf_file_name,
         apply_fix => 1 ,
         check => {
-            'Synopsis' => 'Some patch',
+            'Synopsis' => qr/test TODO/,
+            'Subject' => qr/utf8/,
+            'Subject' => qr/879/,
+            'Subject' => qr/2012/,
             'Bug:0' => 'https://github.com/schwern/perl5i/issues/218',
             'Bug:1' => 'https://github.com/schwern/perl5i/issues/219',
             'Origin' => 'https://github.com/doherty/perl5i',
@@ -24,7 +27,14 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
 
         },
         # file_check_sub => $del_home,
-    }
+    },
+    {
+        name => 'moarvm' ,
+        config_file => $conf_file_name,
+        check => {
+            'Synopsis' => qr/Configure.pl/,
+        }
+    },
 );
 
 
